@@ -17,17 +17,18 @@ from scancode_config import scancode_root_dir
 
 
 def run_scan_plain(
-    options, 
-    cwd=None, 
-    test_mode=True, 
-    expected_rc=0, 
-    env=None, 
+    options,
+    cwd=None,
+    test_mode=True,
+    expected_rc=0,
+    env=None,
     retry=True,
 ):
     """
     Run a scan as a plain subprocess. Return rc, stdout, stderr.
     """
-    from commoncode.command import execute2
+
+    from commoncode.command import execute
 
     options = add_windows_extra_timeout(options)
 
@@ -39,7 +40,7 @@ def run_scan_plain(
 
     scmd = u'scancode'
     scan_cmd = os.path.join(scancode_root_dir, scmd)
-    rc, stdout, stderr = execute2(
+    rc, stdout, stderr = execute(
         cmd_loc=scan_cmd,
         args=options,
         cwd=cwd,
@@ -51,7 +52,7 @@ def run_scan_plain(
         time.sleep(1)
         if '--verbose' not in options:
             options.append('--verbose')
-        result = rc, stdout, stderr = execute2(
+        result = rc, stdout, stderr = execute(
             cmd_loc=scan_cmd,
             args=options,
             cwd=cwd,
@@ -229,6 +230,22 @@ def load_json_result_from_string(string, remove_file_date=False):
     return scan_results
 
 
+def cleanup_scan(scan_results, remove_file_date=False):
+    """
+    Cleanup in place the ``scan_results`` mapping for dates, headers and
+    other variable data that break tests otherwise.
+    """
+    # clean new headers attributes
+    streamline_headers(scan_results.get('headers', []))
+    # clean file_level attributes
+    for scanned_file in scan_results['files']:
+        streamline_scanned_file(scanned_file, remove_file_date)
+
+    # TODO: remove sort, this should no longer be needed
+    scan_results['files'].sort(key=lambda x: x['path'])
+    return scan_results
+
+
 def streamline_errors(errors):
     """
     Modify the `errors` list in place to make it easier to test
